@@ -76,7 +76,10 @@ idle_get_names(void)
 unsigned
 idle_parse_name(const char *name)
 {
+#if !CLANG_CHECK_VERSION(3,6)
+	/* disabled on clang due to -Wtautological-pointer-compare */
 	assert(name != nullptr);
+#endif
 
 	for (unsigned i = 0; idle_names[i] != nullptr; ++i)
 		if (StringEqualsCaseASCII(name, idle_names[i]))
