@@ -109,6 +109,13 @@ struct CurlInputStream final : public AsyncInputStream {
 	 */
 	void FreeEasyIndirect();
 
+	/**
+	 * Called when a new response begins.  This is used to discard
+	 * headers from previous responses (for example authentication
+	 * and redirects).
+	 */
+	void ResponseBoundary();
+
 	void HeaderReceived(const char *name, std::string &&value);
 
 	size_t DataReceived(const void *ptr, size_t size);
@@ -597,6 +604,24 @@ CurlInputStream::~CurlInputStream()
 	FreeEasyIndirect();
 }
 
+inline void
+CurlInputStream::ResponseBoundary()
+{
+	/* undo all effects of HeaderReceived() because the previous
+	   response was not applicable for this stream */
+
+	if (IsSeekPending())
+		/* don't update metadata while seeking */
+		return;
+
+	seekable = false;
+	size = UNKNOWN_SIZE;
+	ClearMimeType();
+	ClearTag();
+
+	// TODO: reset the IcyInputStream?
+}
+
 inline void
 CurlInputStream::HeaderReceived(const char *name, std::string &&value)
 {
@@ -645,6 +670,11 @@ input_curl_headerfunction(void *ptr, size_t size, size_t nmemb, void *stream)
 	size *= nmemb;
 
 	const char *header = (const char *)ptr;
+	if (size > 5 && memcmp(header, "HTTP/", 5) == 0) {
+		c.ResponseBoundary();
+		return size;
+	}
+
 	const char *end = header + size;
 
 	char name[64];
@@ -720,10 +750,10 @@ CurlInputStream::InitEasy(Error &error)
 			 input_curl_writefunction);
 	curl_easy_setopt(easy, CURLOPT_WRITEDATA, this);
 	curl_easy_setopt(easy, CURLOPT_HTTP200ALIASES, http_200_aliases);
-	curl_easy_setopt(easy, CURLOPT_FOLLOWLOCATION, 1);
-	curl_easy_setopt(easy, CURLOPT_NETRC, 1);
-	curl_easy_setopt(easy, CURLOPT_MAXREDIRS, 5);
-	curl_easy_setopt(easy, CURLOPT_FAILONERROR, true);
+	curl_easy_setopt(easy, CURLOPT_FOLLOWLOCATION, 1l);
+	curl_easy_setopt(easy, CURLOPT_NETRC, 1l);
+	curl_easy_setopt(easy, CURLOPT_MAXREDIRS, 5l);
+	curl_easy_setopt(easy, CURLOPT_FAILONERROR, 1l);
 	curl_easy_setopt(easy, CURLOPT_ERRORBUFFER, error_buffer);
 	curl_easy_setopt(easy, CURLOPT_NOPROGRESS, 1l);
 	curl_easy_setopt(easy, CURLOPT_NOSIGNAL, 1l);
